@@ -51,12 +51,14 @@ class TestException(Exception):
 
 class BaseTestCaseMixin:
 
+    databases = ['default', 'security']
+
     @data_provider
     def create_user(self, username='test', email='test@test.cz'):
         return User.objects._create_user(username, email, 'test', is_staff=True, is_superuser=True)
 
 
-class CeleryHealthCheckCommandTestCaseMixin:
+class CeleryHealthCheckCommandTestCaseMixin(BaseTestCaseMixin):
 
     @data_provider
     def create_waiting_celery_task_log(self, task_uuid=uuid.uuid4(), name=None,
@@ -242,7 +244,6 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         output_logged_request = OutputLoggedRequest.objects.get()
         assert_equal(output_logged_request.related_objects.count(), 2)
         user_related_object, input_request_related_object = output_logged_request.related_objects.all()
-
         assert_equal(user_related_object.object, user)
         assert_equal(input_request_related_object.object, InputLoggedRequest.objects.first())
 
@@ -318,14 +319,14 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_http_too_many_requests(self.get('/extra-throttling/'))
 
     @responses.activate
-    def test_output_logged_requests_with_atomic_block_should_not_be_logged_if_exception_is_raised(self):
+    def test_output_logged_requests_with_atomic_block_should_be_logged_if_exception_is_raised(self):
         responses.add(responses.GET, 'http://test.cz', body='test')
         with assert_raises(TestException):
             with transaction.atomic():
                 requests.get('http://test.cz')
                 assert_equal(OutputLoggedRequest.objects.count(), 1)
                 raise TestException
-        assert_equal(OutputLoggedRequest.objects.count(), 0)
+        assert_equal(OutputLoggedRequest.objects.count(), 1)
 
     @responses.activate
     def test_output_logged_requests_with_atomic_and_log_atomic_block_should_be_logged_if_exception_is_raised(self):
@@ -462,7 +463,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         )
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30)
     def test_celery_task_should_have_rightly_set_stale_time(self):
         sum_task.apply_async(args=(5, 8))
         celery_task_log = CeleryTaskLog.objects.get()
@@ -471,7 +472,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(celery_task_log.stale, now() + timedelta(seconds=30))
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
     def test_celery_task_should_have_rightly_set_expires_time(self):
         sum_task.apply_async(args=(5, 8))
         celery_task_log = CeleryTaskLog.objects.get()
@@ -480,7 +481,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(celery_task_log.stale, now() + timedelta(seconds=30))
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
     def test_celery_task_should_have_rightly_set_expires_time_if_soft_time_limit_is_set_in_task_call(self):
         sum_task.apply_async(args=(5, 8), time_limit=20)
         celery_task_log = CeleryTaskLog.objects.get()
@@ -489,7 +490,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(celery_task_log.stale, now() + timedelta(seconds=30))
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
     def test_celery_task_should_have_rightly_set_expires_time_if_stale_time_limit_is_set_in_task_call(self):
         sum_task.apply_async(args=(5, 8), stale_time_limit=100)
         celery_task_log = CeleryTaskLog.objects.get()
@@ -498,7 +499,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(celery_task_log.expires, now() + timedelta(seconds=90))
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
     def test_celery_task_should_have_rightly_set_expires_time_according_to_default_task_stale_limit_value(self):
         error_task.apply_async()
         celery_task_log = CeleryTaskLog.objects.get()
@@ -507,7 +508,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(celery_task_log.expires, now() + timedelta(seconds=60 * 60 - 10))
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
     def test_stale_waiting_celery_task_should_be_set_as_failed_with_command(self):
         sum_task.apply_async(args=(5, 8))
         celery_task_log = CeleryTaskLog.objects.create(
@@ -526,7 +527,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_false(CeleryTaskLog.objects.filter_processing().exists())
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
     def test_stale_failed_celery_task_should_not_be_set_as_failed_with_command(self):
         sum_task.apply_async(args=(5, 8))
         celery_task_log = CeleryTaskLog.objects.create(
@@ -553,7 +554,7 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         assert_equal(celery_task_log.refresh_from_db().state, CeleryTaskLogState.FAILED)
 
     @freeze_time(now())
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=30, CELERYD_TASK_TIME_LIMIT=10)
     def test_stale_succeded_celery_task_should_not_be_set_as_succeeded_with_command(self):
         sum_task.apply_async(args=(5, 8))
         celery_task_log = CeleryTaskLog.objects.create(
@@ -579,20 +580,20 @@ class SecurityTestCase(BaseTestCaseMixin, ClientTestCase):
         test_call_command('set_celery_task_log_state')
         assert_equal(celery_task_log.refresh_from_db().state, CeleryTaskLogState.SUCCEEDED)
 
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=None)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=None)
     def test_unique_task_shoud_have_set_stale_limit(self):
         with assert_raises(CeleryError):
             unique_task.delay()
-        with override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=10):
+        with override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=10):
             with assert_not_raises(CeleryError):
                 unique_task.delay()
 
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=5)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=5)
     def test_apply_async_and_get_result_should_return_time_error_for_zero_timeout(self):
         with assert_raises(TimeoutError):
             unique_task.apply_async_and_get_result(timeout=0)
 
-    @override_settings(DJANGO_CELERY_EXTENSIONS_TASK_STALE_TIME_LIMIT=5)
+    @override_settings(DJANGO_CELERY_EXTENSIONS_DEFAULT_TASK_STALE_TIME_LIMIT=5)
     def test_apply_async_and_get_result_should_return_task_result(self):
         assert_equal(unique_task.apply_async_and_get_result(), 'unique')
 
